@@ -8,10 +8,10 @@ import numpy as np
 import torch
 
 
-class VanilaDQN(AbstractAgent):
+class VanilaDQN(torch.nn.Module, AbstractAgent):
     """
     """
-    def __init__(self, settings, agent_modules, env=None, is_learner=True):
+    def __init__(self, settings, agent_modules, env=None, learning=True):
         """
         """
         super(VanilaDQN, self).__init__()
@@ -19,7 +19,7 @@ class VanilaDQN(AbstractAgent):
         #
         self.settings = settings
         self.qnet_class = agent_modules["qnet"]
-        self.qnet_base = self.qnet_class(self.settings.agent_settings)
+        self.qnet_base = self.qnet_class(self.settings)
         self.qnet_base.eval_mode()
         self.env = env
         #
@@ -31,9 +31,9 @@ class VanilaDQN(AbstractAgent):
         self.num_actions = self.settings.agent_settings["num_actions"]
         self.gamma = torch.tensor(self.settings.agent_settings["gamma"])
         #
-        self.is_learner = is_learner
-        if self.is_learner:
-            self.qnet_learner = self.qnet_class(self.settings.agent_settings)
+        self.learning = learning
+        if self.learning:
+            self.qnet_learner = self.qnet_class(self.settings)
             self.update_base_net(1.0)
             self.merge_ksi = self.settings.agent_settings["merge_ksi"]
         #
@@ -77,17 +77,17 @@ class VanilaDQN(AbstractAgent):
         #
 
     #
-    def standardize_batch(self, batch_data):
-        """ batch_data["data"]: list of (s, a, r, s', info)
+    def standardize_batch(self, batch_sample):
+        """ batch_sample["data"]: list of (s, a, r, s', info)
         """
-        list_s, list_a, list_r, list_p, list_info = list(zip(*batch_data["data"]))
+        list_s, list_a, list_r, list_p, list_info = list(zip(*batch_sample["data"]))
         #
         s_std = self.qnet_base.trans_list_observations(list_s)
         #
         batch_std = {}
         batch_std["s_std"] = s_std
-        batch_std["a"] = torch.tensor(list_a)
-        batch_std["r"] = torch.tensor(list_r)
+        batch_std["a"] = torch.tensor(list_a).to(self.settings.device)
+        batch_std["r"] = torch.tensor(list_r).to(self.settings.device)
         #
         p_std = self.qnet_base.trans_list_observations(list_p)
         batch_std["p_std"] = p_std
@@ -97,7 +97,6 @@ class VanilaDQN(AbstractAgent):
 
     def optimize(self, batch_std, buffer):
         """ optimization step
-            batch_data["data"]: list of (s, a, r, s', info)
         """
         # s
         s_std = batch_std["s_std"]
@@ -136,7 +135,7 @@ class VanilaDQN(AbstractAgent):
         """
         merge_function = self.qnet_base.merge_weights_function()
         merge_function(self.qnet_base, another.qnet_base, 1.0)
-        if self.is_learner:
+        if self.learning:
             merge_function(self.qnet_learner, another.qnet_learner, 1.0)
         
     #
@@ -158,7 +157,7 @@ class VanilaDQN(AbstractAgent):
         """
         """
         dict_base = self.qnet_base.state_dict()
-        if self.is_learner:
+        if self.learning:
             dict_learner = self.qnet_learner.state_dict()
         else:
             dict_learner = {}
@@ -173,7 +172,7 @@ class VanilaDQN(AbstractAgent):
         dict_all = load_data_from_pkl(model_path)
         dict_base = dict_all["qnet_base"]
         self.qnet_base.load_state_dict(dict_base)
-        if self.is_learner:
+        if self.learning:
             dict_learner = dict_all["qnet_learner"]
             self.qnet_learner.load_state_dict(dict_learner)
         #
